@@ -132,8 +132,11 @@ class Observation:
                 ids.extend(id_to_index[id] for id in self.ids[etype])
             return np.array(ids, dtype=np.int64)
         else:
-            return np.arange(
-                sum(len(self.ids[etype]) for etype in obs_space.entities),
+            return np.array(
+                np.arange(
+                    sum(len(self.ids[etype]) for etype in obs_space.entities),
+                    dtype=np.int64,
+                ),
                 dtype=np.int64,
             )
 
@@ -154,8 +157,11 @@ class Observation:
                 ids.extend(id_to_index[id] for id in self.ids[etype])
             return np.array(ids, dtype=np.int64)
         else:
-            return np.arange(
-                sum(len(self.ids[etype]) for etype in obs_space.entities),
+            return np.array(
+                np.arange(
+                    sum(len(self.ids[etype]) for etype in obs_space.entities),
+                    dtype=np.int64,
+                ),
                 dtype=np.int64,
             )
 
